@@ -4,7 +4,7 @@ from pulse_ssz.exceptions import DeserializationError, SerializationError
 from pulse_ssz.sedes.basic import BasicSedes
 
 
-class String(BasicSedes[int, int]):
+class String(BasicSedes[str, str]):
     def __init__(self, num_bits: int) -> None:
         if num_bits % 8 != 0:
             raise ValueError("Number of bits must be a multiple of 8")
